/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.2 Baustellensimulation
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.simbaustelle.prognose.mdm;

import java.util.List;

import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.dav.daf.main.Data.Array;
import de.bsvrz.ibv.simbaustelle.verwaltung.BssStau;

/**
 * Wrapper für den Datensatz zum Versand der Prognosedaten einer MdM-Baustelle.
 * 
 * @author BitCtrl Systems GmbH, Uwe Peuker
 */
public final class MdmPrognoseDaten {

	private Data data;

	public MdmPrognoseDaten(Data datenSatz) {

		data = datenSatz;
		setSimulationErfolgreich(false);
		setAuftragGeber(null);
		setBemerkung(null);
		setFehlerMeldung("Simulation noch nicht implementiert");
	}

	public void setSimulationErfolgreich(boolean simulationErfolgreich) {
		if (simulationErfolgreich) {
			data.getUnscaledValue("SimulationErfolgreich").setText("Ja");
		} else {
			data.getUnscaledValue("SimulationErfolgreich").setText("Nein");
		}
	}

	public void setAuftragGeber(String auftragGeber) {
		if (auftragGeber == null) {
			data.getTextValue("Auftraggeber").setText("");
		} else {
			data.getTextValue("Auftraggeber").setText(auftragGeber);
		}
	}

	public void setBemerkung(String bemerkung) {
		if (bemerkung == null) {
			data.getTextValue("Bemerkung").setText("");
		} else {
			data.getTextValue("Bemerkung").setText(bemerkung);
		}
	}

	public void setFehlerMeldung(String fehlerMeldung) {
		if (fehlerMeldung == null) {
			data.getTextValue("Fehlermeldung").setText("");
		} else {
			data.getTextValue("Fehlermeldung").setText(fehlerMeldung);
		}
	}

	public void setStauListe(List<BssStau> stauListe) {

		Array array = data.getArray("BaustellenSimulation");
		array.setLength(stauListe.size());

		int idx = 0;
		for (BssStau stau : stauListe) {
			Data eintrag = array.getItem(idx++);
			eintrag.getTimeValue("StartZeit").setMillis(stau.getStartZeit());
			eintrag.getTimeValue("Dauer").setMillis(stau.getDauer());
			eintrag.getScaledValue("MaxLänge").set(stau.getMaxLaenge());
			eintrag.getTimeValue("MaxLängeZeit").setMillis(stau.getMaxLaengeZeit());
			eintrag.getTimeValue("VerlustZeit").setMillis(stau.getVerlustZeit());
		}
	}
}
