/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.2 Baustellensimulation
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.simbaustelle.simbaustelle;

import java.util.ResourceBundle;
import java.util.logging.Level;

import de.bsvrz.sys.funclib.bitctrl.daf.LogNachricht;
import de.bsvrz.sys.funclib.debug.Debug;
import de.bsvrz.sys.funclib.operatingMessage.MessageGrade;

/**
 * die allgemeinen Meldungen innerhalb der Softwareeinheit
 * "Baustellensimulation".
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public enum BssMessage implements LogNachricht {

	/* Meldungen die mit dem Level ERROR ausgegeben werden sollen . */

	/** Parameter 1) Baustelle 2) Fehlermeldung. */
	ErrorSendeSimulationsErgebnis(Debug.ERROR),

	/* Meldungen die mit dem Level WARNING ausgegeben werden sollen . */

	/** Parameter 1) Baustelle 2) Intervall 3) Fehlermeldung. */
	WarningGanglinienAbfrage(Debug.WARNING),

	/** Parameter 1) die Baustelle 2) der Zeitraum. */
	WarningUngueltigerSimulationsZeitraum(Debug.WARNING),

	/** Parameter 1) die Baustelle 2) die Fehlermeldung. */
	WarningFehlendeSimulationsDaten(Debug.WARNING);

	/**
	 * das verwendete Ressource-Bundle.
	 */
	private static final ResourceBundle RESOURCE_BUNDLE = ResourceBundle.getBundle(BssMessage.class.getCanonicalName());

	/** der Level mit dem die Meldung ausgegeben werden soll. */
	private Level level;

	/**
	 * Initialisiert das Objekt.
	 *
	 * @param level
	 *            der Log-Level.
	 */
	BssMessage(final Level level) {
		this.level = level;
	}

	@Override
	public MessageGrade getBmvLevel() {
		MessageGrade result = null;
		if (level.equals(Debug.WARNING)) {
			result = MessageGrade.WARNING;
		} else if (level.equals(Debug.ERROR)) {
			result = MessageGrade.ERROR;
		}
		return result;
	}

	@Override
	public Level getLogLevel() {
		return level;
	}

	@Override
	public ResourceBundle getResourceBundle() {
		return BssMessage.RESOURCE_BUNDLE;
	}

	@Override
	public String toString() {
		return getResourceBundle().getString(name());
	}

}
