/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.2 Baustellensimulation
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.simbaustelle.verwaltung;

import de.bsvrz.sys.funclib.bitctrl.modell.verkehr.objekte.MessQuerschnittAllgemein;

/**
 * die Repräsentation eines auszuführenden Simulationsauftrags.
 * 
 * @author BitCtrl Systems GmbH, Uwe Peuker
 */
public abstract class SimulationsAuftrag {

	/** die Baustelle, für die eine Simulation ausgeführt werden soll. */
	private final BaustellenSchnittstelle baustelle;

	/** der Name des Auftraggebers für die Simulation. */
	private final String auftragGeber;

	/** ein beschreibender Text für den Simulationsauftrag. */
	private final String bemerkung;

	/** der optional vorgegebene MQ vor der Baustelle. */
	private final MessQuerschnittAllgemein berechnungsMq;

	private Long restKapazitaet;
	private Long schrittWeiteInMsec;
	private long endZeit;
	private long startZeit;

	
	/**
	 * Konstruktor. Die Funktion legt einen Auftrag für die übergebene Baustelle mit
	 * den übergebenen Auftraggeberinformationen an.
	 *
	 * @param baustelle
	 *            die Baustelle
	 * @param auftragGeber
	 *            der Name des Auftraggebers
	 * @param bemerkung
	 *            beschreibender Text
	 * @param berechnungsMq
	 *            der MQ für die Bestimmung des zufließenden Verkehrs
	 */
	public SimulationsAuftrag(final BaustellenSchnittstelle baustelle, final String auftragGeber,
			final String bemerkung, final MessQuerschnittAllgemein berechnungsMq) {
		this.baustelle = baustelle;
		this.auftragGeber = auftragGeber;
		this.bemerkung = bemerkung;
		this.berechnungsMq = berechnungsMq;
	}

	public BaustellenSchnittstelle getBaustelle() {
		return baustelle;
	}

	public String getBemerkung() {
		return bemerkung;
	}

	public MessQuerschnittAllgemein getBerechnungsMq() {
		return berechnungsMq;
	}

	public String getAuftragGeber() {
		return auftragGeber;
	}

	public abstract boolean isManuell();

	public void setStartZeit(long startZeit) {
		this.startZeit = startZeit;
	}

	public long getStartZeit() {
		return startZeit;
	}

	public void setEndZeit(long endZeit) {
		this.endZeit = endZeit;
	}

	public long getEndZeit() {
		return endZeit;
	}

	public void setSchrittWeiteInMsec(Long schrittWeiteInMsec) {
		this.schrittWeiteInMsec = schrittWeiteInMsec;
	}

	public Long getSchrittWeiteInMsec() {
		return schrittWeiteInMsec;
	}

	public void setRestKapazitaet(Long restKapazitaet) {
		this.restKapazitaet = restKapazitaet;
	}

	public Long getRestKapazitaet() {
		return restKapazitaet;
	}

	
}
