/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.2 Baustellensimulation
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.simbaustelle.verwaltung;

import java.util.ArrayList;
import java.util.List;

import de.bsvrz.sys.funclib.debug.Debug;
import de.bsvrz.sys.funclib.operatingMessage.MessageGrade;
import de.bsvrz.sys.funclib.operatingMessage.MessageSender;
import de.bsvrz.sys.funclib.operatingMessage.MessageType;

/**
 * sammelt die Aufträge und führt diese im Hintergrund aus, um die Simulation
 * von der restlichen Datenverteilerkommunikation zu entkoppeln.
 */
class SimulationsAuftragsVerwalter extends Thread {

	private static final Debug LOGGER = Debug.getLogger();

	/**
	 * die Liste der auszuführenden Aufträge.
	 */
	private final List<SimulationsAuftrag> auftragsListe = new ArrayList<>();

	/**
	 * der Status des Verwalters.
	 */
	private final boolean aktiv = true;

	/**
	 * Konstruktor.
	 */
	SimulationsAuftragsVerwalter() {
		super("BaustellenSimulationsAuftragsVerwalter");
		setDaemon(true);
	}

	/**
	 * fügt der Auftragsverwaltung einen neuen Auftrag hinzu.
	 *
	 * @param auftrag
	 *            der hinzuzufügende Auftrag
	 */
	public void addAuftrag(final SimulationsAuftrag auftrag) {
		synchronized (auftragsListe) {
			auftragsListe.add(auftrag);
		}
		synchronized (this) {
			this.notifyAll();
		}
	}

	@Override
	public void run() {
		while (aktiv) {
			SimulationsAuftrag auftrag = null;
			synchronized (auftragsListe) {
				if (auftragsListe.size() > 0) {
					auftrag = auftragsListe.get(0);
					auftragsListe.remove(0);
				} else {
					LOGGER.finest("Auftragsliste ist leer");
				}
			}
			if (auftrag != null) {
				final String messageText;
				if (auftrag.getBerechnungsMq() == null) {
					messageText = "Manuelle Simulation der Baustelle: " + auftrag.getBaustelle().getName()
							+ " angefordert von " + auftrag.getAuftragGeber() + ", Bemerkung: " + auftrag.getBemerkung();
				} else {
					messageText = "Manuelle Simulation der Baustelle: " + auftrag.getBaustelle().getName()
							+ " angefordert von " + auftrag.getAuftragGeber() + ", Bemerkung: " + auftrag.getBemerkung()
							+ " Berechnungs-MQ: " + auftrag.getBerechnungsMq();
				}
				LOGGER.fine(messageText);
				MessageSender.getInstance().sendMessage(MessageType.APPLICATION_DOMAIN, MessageGrade.INFORMATION,
						messageText);

				auftrag.getBaustelle().simuliere(auftrag);
			} else {
				synchronized (this) {
					try {
						if (auftragsListe.size() <= 0) {
							this.wait(60000);
						}
					} catch (final InterruptedException e) {
						LOGGER.fine(e.getLocalizedMessage());
						// Schleife wird wiederholt und eventuelle Aufträge
						// vorfristig ausgeführt
					}
				}
			}
		}
	}
}
